@@ -9,15 +9,15 @@ IO::Callback - Emulate file interface for a code reference
 
 =head1 VERSION
 
-Version 1.00
+Version 1.09_01
 
 =cut
 
-our $VERSION = '1.00';
+our $VERSION = '1.09_01';
 
 =head1 SYNOPSIS
 
-C<IO::Callback> provides an easy way to produce a phoney read-only filehandle that calls back to your own code when it needs data to satisfy a read. This is useful if you want to use a library module that expects to read data from a filehandle, but you want the data to come from some other source, and there is too much data to read it all into memory and use L<IO::String> or similar.
+C<IO::Callback> provides an easy way to produce a phoney read-only filehandle that calls back to your own code when it needs data to satisfy a read. This is useful if you want to use a library module that expects to read data from a filehandle, but you want the data to come from some other source and you don't want to read it all into memory and use L<IO::String>.
 
     use IO::Callback;
 
@@ -344,6 +344,7 @@ sub getline
     *$self->{R} or return $self->_ebadf;
     return if *$self->{Eof} || *$self->{Err};
     my $buf = *$self->{Buf};
+    $. = *$self->{lno};
 
     unless (defined $/) {  # slurp
         1 while $self->_doread;
@@ -516,6 +517,8 @@ sub printf
 sub getpos
 {
     my $self = shift;
+
+    $. = *$self->{lno};
     return *$self->{Pos};
 }
 *tell = \&getpos;
@@ -553,7 +556,9 @@ sub write
         croak "Negative length" if $len < 0;
         if (@_ > 2) {
             $off = $_[2] || 0;
-            croak "Offset outside string" if $off >= $slen and $off > 0;
+            if ( $off >= $slen and $off > 0 and ($] < 5.011 or $off > $slen) ) {
+                croak "Offset outside string";
+            }
             if ($off < 0) {
                 $off += $slen;
                 croak "Offset outside string" if $off < 0;
@@ -616,7 +621,7 @@ Fails to inter-operate with some library modules that read or write filehandles
 
 =back
 
-Please report any other bugs or feature requests to C<bug-io-callback at rt.cpan.org>, or through
+Please report any other bugs or feature requests to C<bug- at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=IO::Callback>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
@@ -656,12 +661,16 @@ L<IO::String>, L<IO::Stringy>, L<perlfunc/open>
 
 Adapted from code in L<IO::String> by Gisle Aas.
 
+=head1 MANITAINER
+
+This module is currently being maintained by Toby Inkster (TOBYINK)
+for bug fixes. No substantial changes or new features are planned.
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 1998-2005 Gisle Aas.
 
-Copyright 2009 Dave Taylor, all rights reserved.
-
+Copyright 2009-2010 Dave Taylor.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
